"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UseCls = void 0;
require("reflect-metadata");
const cls_service_manager_1 = require("../cls-service-manager");
const cls_constants_1 = require("../cls.constants");
const cls_options_1 = require("../cls.options");
function UseCls(maybeOptions) {
    return (target, propertyKey, descriptor) => {
        const options = Object.assign(Object.assign({}, new cls_options_1.ClsDecoratorOptions()), maybeOptions);
        const cls = cls_service_manager_1.ClsServiceManager.getClsService();
        const original = descriptor.value;
        // console.log('original is', original?.toString());
        if (typeof original !== 'function') {
            throw new Error(`The @UseCls decorator can be only used on functions, but ${propertyKey.toString()} is not a function.`);
        }
        descriptor.value = function (...args) {
            return cls.run(async () => {
                var _a;
                if (options.generateId) {
                    const id = await ((_a = options.idGenerator) === null || _a === void 0 ? void 0 : _a.apply(this, args));
                    cls.set(cls_constants_1.CLS_ID, id);
                }
                if (options.setup) {
                    await options.setup.apply(this, [cls, ...args]);
                }
                if (options.resolveProxyProviders) {
                    await cls.resolveProxyProviders();
                }
                return original.apply(this, args);
            });
        };
        copyMetadata(original, descriptor.value);
    };
}
exports.UseCls = UseCls;
/**
 * Copies all metadata from one object to another.
 * Useful for overwriting function definition in
 * decorators while keeping all previously
 * attached metadata
 *
 * @param from object to copy metadata from
 * @param to object to copy metadata to
 */
function copyMetadata(from, to) {
    const metadataKeys = Reflect.getMetadataKeys(from);
    metadataKeys.map((key) => {
        const value = Reflect.getMetadata(key, from);
        Reflect.defineMetadata(key, value, to);
    });
}
//# sourceMappingURL=use-cls.decorator.js.map