"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ClsDecoratorOptions = exports.ClsInterceptorOptions = exports.ClsGuardOptions = exports.ClsMiddlewareOptions = exports.ClsModuleOptions = void 0;
const getRandomString = () => Math.random().toString(36).slice(-8);
class ClsModuleOptions {
    constructor() {
        /**
         * whether to make the module global, so you don't need
         * to import ClsModule.forFeature()` in other modules
         */
        this.global = false;
    }
}
exports.ClsModuleOptions = ClsModuleOptions;
class ClsMiddlewareOptions {
    constructor() {
        /**
         * the function to generate request ids inside the middleware
         */
        this.idGenerator = getRandomString;
        /**
         * Whether to resolve proxy providers as a part
         * of the CLS context registration
         *
         * Default: `true`
         */
        this.resolveProxyProviders = true;
        /**
         * Whether to store the Request object to the CLS
         * It will be available under the CLS_REQ key
         */
        this.saveReq = true;
        /**
         * Whether to store the Response object to the CLS
         * It will be available under the CLS_RES key
         */
        this.saveRes = false;
        /**
         * Set to true to set up the context using a call to
         * `AsyncLocalStorage#enterWith` instead of wrapping the
         * `next()` call with the safer `AsyncLocalStorage#run`
         *
         * Most of the time this should not be necessary, but
         * some frameworks are known to lose the context wih `run`.
         */
        this.useEnterWith = false;
    }
}
exports.ClsMiddlewareOptions = ClsMiddlewareOptions;
class ClsGuardOptions {
    constructor() {
        /**
         * the function to generate request ids inside the guard
         */
        this.idGenerator = getRandomString;
        /**
         * Whether to resolve proxy providers as a part
         * of the CLS context registration
         *
         * Default: `true`
         */
        this.resolveProxyProviders = true;
    }
}
exports.ClsGuardOptions = ClsGuardOptions;
class ClsInterceptorOptions {
    constructor() {
        /**
         * the function to generate request ids inside the interceptor
         */
        this.idGenerator = getRandomString;
        /**
         * Whether to resolve proxy providers as a part
         * of the CLS context registration
         *
         * Default: `true`
         */
        this.resolveProxyProviders = true;
    }
}
exports.ClsInterceptorOptions = ClsInterceptorOptions;
class ClsDecoratorOptions {
    constructor() {
        /**
         * The function to generate request ids inside the interceptor.
         *
         * Takes the same parameters in the same order as the decorated function.
         *
         * Note: To avoid type errors, you must list all parameters, even if they're not used,
         * or type the decorator as `@UseCls<[arg1: Type1, arg2: Type2]>()`
         */
        this.idGenerator = getRandomString;
        /**
         * Whether to resolve proxy providers as a part
         * of the CLS context registration
         *
         * Default: `false`
         */
        this.resolveProxyProviders = false;
    }
}
exports.ClsDecoratorOptions = ClsDecoratorOptions;
//# sourceMappingURL=cls.options.js.map